@@ -20,6 +20,6 @@
 #' @export
 
 chr_uzemi <- function() {
-  result <- downloader("ChrUzemiAOPK-2021-02.rds")
+  result <- .downloader("ChrUzemiAOPK-2021-02.rds")
   result
 }
