@@ -4,7 +4,7 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package).
 #'
-#' The data is current to February 2021 (last update was in 2016). Downloaded size of high resolution shapefile is 10 MB, size of the low res object is negligible (but a working internet is still required, as the object is not interal).
+#' The data is current to February 2021 (last update was in 2016). Downloaded size of high resolution shapefile is 10 MB, size of the low res object is negligible (but a working internet is still required, as the object is not internal).
 #'
 #' @param resolution Should the function return high or low resolution shapefile? Allowed values are "high" (default) and "low". This parameter affects only the geometry column, all other fields remain the same.
 #'
@@ -34,9 +34,9 @@ senat_obvody <- function(resolution = "high") {
   }
 
   if (resolution == "low") {
-    result <- downloader("Senat-low-2021-02.rds")
+    result <- .downloader("Senat-low-2021-02.rds")
   } else {
-    result <- downloader("Senat-high-2021-02.rds")
+    result <- .downloader("Senat-high-2021-02.rds")
   }
   result
 }
